Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(202)

Unified Diff: test/cctest/test-fast-dtoa.cc

Issue 1032007: Rename grisu to fast_dtoa. Get rid of template. (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/cctest/SConscript ('k') | test/cctest/test-grisu3.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/cctest/test-fast-dtoa.cc
===================================================================
--- test/cctest/test-fast-dtoa.cc (revision 4170)
+++ test/cctest/test-fast-dtoa.cc (working copy)
@@ -8,14 +8,14 @@
#include "cctest.h"
#include "diy_fp.h"
#include "double.h"
+#include "fast-dtoa.h"
#include "gay_shortest.h"
-#include "grisu3.h"
using namespace v8::internal;
static const int kBufferSize = 100;
-TEST(GrisuVariousDoubles) {
+TEST(FastDtoaVariousDoubles) {
char buffer[kBufferSize];
int sign;
int length;
@@ -23,45 +23,45 @@
int status;
double min_double = 5e-324;
- status = grisu3(min_double, buffer, &sign, &length, &point);
+ status = FastDtoa(min_double, buffer, &sign, &length, &point);
CHECK(status);
CHECK_EQ(0, sign);
CHECK_EQ("5", buffer);
CHECK_EQ(-323, point);
double max_double = 1.7976931348623157e308;
- status = grisu3(max_double, buffer, &sign, &length, &point);
+ status = FastDtoa(max_double, buffer, &sign, &length, &point);
CHECK(status);
CHECK_EQ(0, sign);
CHECK_EQ("17976931348623157", buffer);
CHECK_EQ(309, point);
- status = grisu3(4294967272.0, buffer, &sign, &length, &point);
+ status = FastDtoa(4294967272.0, buffer, &sign, &length, &point);
CHECK(status);
CHECK_EQ(0, sign);
CHECK_EQ("4294967272", buffer);
CHECK_EQ(10, point);
- status = grisu3(4.1855804968213567e298, buffer, &sign, &length, &point);
+ status = FastDtoa(4.1855804968213567e298, buffer, &sign, &length, &point);
CHECK(status);
CHECK_EQ(0, sign);
CHECK_EQ("4185580496821357", buffer);
CHECK_EQ(299, point);
- status = grisu3(5.5626846462680035e-309, buffer, &sign, &length, &point);
+ status = FastDtoa(5.5626846462680035e-309, buffer, &sign, &length, &point);
CHECK(status);
CHECK_EQ(0, sign);
CHECK_EQ("5562684646268003", buffer);
CHECK_EQ(-308, point);
- status = grisu3(2147483648.0, buffer, &sign, &length, &point);
+ status = FastDtoa(2147483648.0, buffer, &sign, &length, &point);
CHECK(status);
CHECK_EQ(0, sign);
CHECK_EQ("2147483648", buffer);
CHECK_EQ(10, point);
- status = grisu3(3.5844466002796428e+298, buffer, &sign, &length, &point);
- if (status) { // Not all grisu3 variants manage to compute this number.
+ status = FastDtoa(3.5844466002796428e+298, buffer, &sign, &length, &point);
+ if (status) { // Not all FastDtoa variants manage to compute this number.
CHECK_EQ("35844466002796428", buffer);
CHECK_EQ(0, sign);
CHECK_EQ(299, point);
@@ -69,7 +69,7 @@
uint64_t smallest_normal64 = V8_2PART_UINT64_C(0x00100000, 00000000);
double v = Double(smallest_normal64).value();
- status = grisu3(v, buffer, &sign, &length, &point);
+ status = FastDtoa(v, buffer, &sign, &length, &point);
if (status) {
CHECK_EQ(0, sign);
CHECK_EQ("22250738585072014", buffer);
@@ -78,7 +78,7 @@
uint64_t largest_denormal64 = V8_2PART_UINT64_C(0x000FFFFF, FFFFFFFF);
v = Double(largest_denormal64).value();
- status = grisu3(v, buffer, &sign, &length, &point);
+ status = FastDtoa(v, buffer, &sign, &length, &point);
if (status) {
CHECK_EQ(0, sign);
CHECK_EQ("2225073858507201", buffer);
@@ -87,7 +87,7 @@
}
-TEST(GrisuGayShortest) {
+TEST(FastDtoaGayShortest) {
char buffer[kBufferSize];
bool status;
int sign;
@@ -102,10 +102,10 @@
const GayShortest current_test = precomputed[i];
total++;
double v = current_test.v;
- status = grisu3(v, buffer, &sign, &length, &point);
- CHECK_GE(kGrisu3MaximalLength, length);
+ status = FastDtoa(v, buffer, &sign, &length, &point);
+ CHECK_GE(kFastDtoaMaximalLength, length);
if (!status) continue;
- if (length == kGrisu3MaximalLength) needed_max_length = true;
+ if (length == kFastDtoaMaximalLength) needed_max_length = true;
succeeded++;
CHECK_EQ(0, sign); // All precomputed numbers are positive.
CHECK_EQ(current_test.decimal_point, point);
« no previous file with comments | « test/cctest/SConscript ('k') | test/cctest/test-grisu3.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698